summaryrefslogtreecommitdiff
path: root/src/game/bg_public.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/game/bg_public.h')
-rw-r--r--src/game/bg_public.h15
1 files changed, 5 insertions, 10 deletions
diff --git a/src/game/bg_public.h b/src/game/bg_public.h
index bbb2f08b..ba43b1f9 100644
--- a/src/game/bg_public.h
+++ b/src/game/bg_public.h
@@ -117,7 +117,7 @@ typedef enum
PM_NOCLIP, // noclip movement
PM_SPECTATOR, // still run into walls
PM_JETPACK, // jetpack physics
- PM_GRABBED, // like dead, but for when the player is still live
+ PM_GRABBED, // like dead, but for when the player is still alive
PM_DEAD, // no acceleration or turning, but free falling
PM_FREEZE, // stuck in place with no control
PM_INTERMISSION // no movement or status bar
@@ -126,7 +126,7 @@ typedef enum
// pmtype_t categories
#define PM_Paralyzed( x ) ( (x) == PM_DEAD || (x) == PM_FREEZE ||\
(x) == PM_INTERMISSION )
-#define PM_Live( x ) ( (x) == PM_NORMAL || (x) == PM_JETPACK ||\
+#define PM_Alive( x ) ( (x) == PM_NORMAL || (x) == PM_JETPACK ||\
(x) == PM_GRABBED )
typedef enum
@@ -429,13 +429,8 @@ typedef enum
BA_NUM_BUILDABLES
} buildable_t;
-// reward sounds (stored in ps->persistant[PERS_PLAYEREVENTS])
-#define PLAYEREVENT_DENIEDREWARD 0x0001
-#define PLAYEREVENT_GAUNTLETREWARD 0x0002
-#define PLAYEREVENT_HOLYSHIT 0x0004
-
// entityState_t->event values
-// entity events are for effects that take place reletive
+// entity events are for effects that take place relative
// to an existing entities origin. Very network efficient.
// two bits at the top of the entityState->event field
@@ -520,7 +515,7 @@ typedef enum
EV_DEATH3,
EV_OBITUARY,
- EV_GIB_PLAYER, // gib a previously living player
+ EV_GIB_PLAYER,
EV_BUILD_CONSTRUCT,
EV_BUILD_DESTROY,
@@ -570,7 +565,7 @@ typedef enum
MN_CMD_SPEC,
MN_CMD_ALIEN,
MN_CMD_HUMAN,
- MN_CMD_LIVING,
+ MN_CMD_ALIVE,
//alien stuff
MN_A_CLASS,